package com.hw.ems.base.service;

import java.util.List;

import com.hw.ems.base.domain.BaseDnbThreshold;
import com.hw.ems.base.domain.BaseMonitorInfo;
import com.hw.ems.base.domain.vo.TreeSelect;

/**
 * 电阈值信息Service接口
 *
 * @author hw
 * @date 2023-04-20
 */
public interface IBaseDnbThresholdService {
    /**
     * 查询电阈值信息
     *
     * @param objid 电阈值信息主键
     * @return 电阈值信息
     */
    public BaseDnbThreshold selectBaseDnbThresholdByObjid(Long objid);

    /**
     * 查询电阈值信息列表
     *
     * @param baseDnbThreshold 电阈值信息
     * @return 电阈值信息集合
     */
    public List<BaseDnbThreshold> selectBaseDnbThresholdList(BaseDnbThreshold baseDnbThreshold);

    /**
     * 新增电阈值信息
     *
     * @param baseDnbThreshold 电阈值信息
     * @return 结果
     */
    public int insertBaseDnbThreshold(BaseDnbThreshold baseDnbThreshold);

    /**
     * 修改电阈值信息
     *
     * @param baseDnbThreshold 电阈值信息
     * @return 结果
     */
    public int updateBaseDnbThreshold(BaseDnbThreshold baseDnbThreshold);

    /**
     * 批量删除电阈值信息
     *
     * @param objids 需要删除的电阈值信息主键集合
     * @return 结果
     */
    public int deleteBaseDnbThresholdByObjids(Long[] objids);

    /**
     * 删除电阈值信息信息
     *
     * @param objid 电阈值信息主键
     * @return 结果
     */
    public int deleteBaseDnbThresholdByObjid(Long objid);

    public List<TreeSelect> selectMonitorTreeList(BaseMonitorInfo baseMonitorInfo);
}
